pub struct AllocationTotalsV2 {
pub version: u16,
pub allocations: u64,
pub deallocations: u64,
pub allocated_bytes: u64,
pub deallocated_bytes: u64,
pub live_bytes: u64,
pub peak_live_bytes: u64,
}Expand description
Session-window allocation totals with live and peak levels at the end.
Fields
version: u16allocations: u64deallocations: u64allocated_bytes: u64deallocated_bytes: u64live_bytes: u64Process live bytes at the end of the window.
peak_live_bytes: u64Process peak live bytes observed during the window.