pub struct WorkerOccupancyV2 {
pub version: u16,
pub worker_count: u64,
pub active_worker_count: u64,
pub busy_ns: u64,
pub blocked_ns: u64,
pub calls: u64,
pub busiest_busy_ns: u64,
pub median_busy_ns: u64,
pub workers: Vec<WorkerOccupancyRowV2>,
}Expand description
Pool-wide busy versus idle accounting merged from every worker shard.
Fields
version: u16worker_count: u64Workers that registered a counter shard, busy or not.
active_worker_count: u64Workers that recorded at least one outermost span.
busy_ns: u64blocked_ns: u64calls: u64busiest_busy_ns: u64median_busy_ns: u64workers: Vec<WorkerOccupancyRowV2>Trait Implementations
Sourceimpl Clone for WorkerOccupancyV2
impl Clone for WorkerOccupancyV2
Sourcefn clone(&self) -> WorkerOccupancyV2
fn clone(&self) -> WorkerOccupancyV2
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for WorkerOccupancyV2
impl Debug for WorkerOccupancyV2
Sourceimpl<'de> Deserialize<'de> for WorkerOccupancyV2
impl<'de> Deserialize<'de> for WorkerOccupancyV2
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for WorkerOccupancyV2
Sourceimpl PartialEq for WorkerOccupancyV2
impl PartialEq for WorkerOccupancyV2
Sourceimpl Serialize for WorkerOccupancyV2
impl Serialize for WorkerOccupancyV2
impl StructuralPartialEq for WorkerOccupancyV2